@@ -4,14 +4,18 @@ developed by ALBA Synchrotron for Tango Control System
 GPL Licensed 
 """
 
-import sys, panic, traceback
-from utils import Qt, QtCore, QtGui
-from utils import getThemeIcon
-from utils import iValidatedWidget
+import sys
+import panic
+import traceback
+from panic.gui.utils import getThemeIcon
+from panic.gui.utils import iValidatedWidget
+
+from taurus.external.qt import Qt, QtCore, QtGui
+
 
 class PhoneBook(QtGui.QWidget):
-    def __init__(self,parent=None,container=None):
-        QtGui.QWidget.__init__(self,parent)
+    def __init__(self, parent=None, container=None):
+        QtGui.QWidget.__init__(self, parent)
         self._bwi = PhoneBookUi()
         self._bwi.phonebookSetupUi(self)
         self._kontainer = container
@@ -23,13 +27,14 @@ class PhoneBook(QtGui.QWidget):
     def show(self):
         QtGui.QWidget.show(self)
 
-class PhoneBookEntry(iValidatedWidget,object):
+
+class PhoneBookEntry(iValidatedWidget, object):
     def __init__(self, phoneBook):
         self.pB = phoneBook
         self.api = self.pB.api
 
     def addSetupUi(self, addForm):
-        self._Form=addForm
+        self._Form = addForm
         addForm.setObjectName("addForm")
         self.addGridLayout = QtGui.QGridLayout(addForm)
         self.addGridLayout.setObjectName("addGridLayout")
@@ -37,13 +42,13 @@ class PhoneBookEntry(iValidatedWidget,object):
         self.sectionLabel = QtGui.QLabel()
         self.sectionLabel.setObjectName("sectionLabel")
         self.sectionLabel.setText("section:")
-        #self.addGridLayout.addWidget(self.sectionLabel, 0, 0, 1, 1)
+        # self.addGridLayout.addWidget(self.sectionLabel, 0, 0, 1, 1)
         self.sectionCombo = QtGui.QComboBox()
         self.sectionCombo.setObjectName("sectionCombo")
-        sections=['','CONTROLS', 'VACUUM', 'FRONTENDS', 'BEAMLINES', 'On Call']
+        sections = ['', 'CONTROLS', 'VACUUM', 'FRONTENDS', 'BEAMLINES', 'On Call']
         for s in sections:
             self.sectionCombo.addItem(s)
-        #self.addGridLayout.addWidget(self.sectionCombo, 0, 1, 1, 1)
+        # self.addGridLayout.addWidget(self.sectionCombo, 0, 1, 1, 1)
 
         self.nameLabel = QtGui.QLabel(addForm)
         self.nameLabel.setObjectName("emailLabel")
@@ -91,75 +96,77 @@ class PhoneBookEntry(iValidatedWidget,object):
         QtCore.QMetaObject.connectSlotsByName(addForm)
 
     def addRetranslateUi(self, addForm):
-        addForm.setWindowTitle(QtGui.QApplication.translate("addForm", "Add Recipient", None, QtGui.QApplication.UnicodeUTF8))
-        self.addButton.setText(QtGui.QApplication.translate("addForm", "Add", None, QtGui.QApplication.UnicodeUTF8))
+        addForm.setWindowTitle(QtGui.QApplication.translate("addForm", "Add Recipient", None))
+        self.addButton.setText(QtGui.QApplication.translate("addForm", "Add", None))
         self.addButton.setIcon(getThemeIcon("list-add"))
         self.addButton.setToolTip("Add person to the list")
-        self.cancelButton.setText(QtGui.QApplication.translate("addForm", "Cancel", None, QtGui.QApplication.UnicodeUTF8))
+        self.cancelButton.setText(QtGui.QApplication.translate("addForm", "Cancel", None))
         self.cancelButton.setIcon(getThemeIcon("process-stop"))
         self.cancelButton.setToolTip("Cancel")
         addForm.resize(250, 150)
 
-        QtCore.QObject.connect(self.addButton,QtCore.SIGNAL("clicked()"), self.onAdd)
-        QtCore.QObject.connect(self.cancelButton,QtCore.SIGNAL("clicked()"), self.onCancel)
-        QtCore.QObject.connect(self.smsCheckBox,QtCore.SIGNAL("stateChanged(int)"), self.onCheckStateChanged)
+        self.addButton.clicked.connect(self.onAdd)
+        self.cancelButton.clicked.connect(self.onCancel)
+        self.smsCheckBox.stateChanged.connect(self.onCheckStateChanged)
 
     def onAdd(self):
         try:
             section = str(self.sectionCombo.currentText())
             name = str(self.nameLine.text()).upper()
-            name = '%'+name if not name.startswith('%') else name
+            name = '%' + name if not name.startswith('%') else name
             email = str(self.emailLine.text())
-            if not self.validate('Phonebook.onAdd(%s,%s,%s)'%(section,name,email)):
+            if not self.validate('Phonebook.onAdd({},{},{})'.format(section, name, email)):
                 return
-            if self.smsCheckBox.isChecked(): 
+            if self.smsCheckBox.isChecked():
                 number = str(self.smsLine.text())
-                number =  'SMS:'+number if not number.startswith('SMS:') else number
-                if number: email+=','+number
-            if (not name):
-                message='Type name\n'
+                number = 'SMS:' + number if not number.startswith('SMS:') else number
+                if number: email += ',' + number
+            if not name:
+                message = 'Type name\n'
                 raise Exception(message)
-            elif (not email and not number):
-                message='Type email address\n'
+            elif not email and not number:
+                message = 'Type email address\n'
                 raise Exception(message)
             else:
-                alarms = [a for a,v in self.api.items() if name in v.receivers]
-                v = QtGui.QMessageBox.warning(None,'Phonebook[%s]'%name,\
-                    'The following alarms will be afected:\n\n'+
-                    '\n'.join(alarms)+'\n\nDo you want to proceed?',
-                    QtGui.QMessageBox.Ok|QtGui.QMessageBox.Cancel)
-                
-                if v == QtGui.QMessageBox.Ok: 
-                    print 'onAdd.edit_phoneBook(%s,%s,(%s))'%(name,email,section)
-                    self.api.edit_phonebook(name,email,section)
+                alarms = [a for a, v in self.api.items() if name in v.receivers]
+                v = QtGui.QMessageBox.warning(None, 'Phonebook[{}]'.format(name),
+                                              'The following alarms will be afected:\n\n' +
+                                              '\n'.join(alarms) + '\n\nDo you want to proceed?',
+                                              QtGui.QMessageBox.Ok | QtGui.QMessageBox.Cancel)
+
+                if v == QtGui.QMessageBox.Ok:
+                    print('onAdd.edit_phoneBook({},{},({}))'.format(name, email, section))
+                    self.api.edit_phonebook(name, email, section)
                     devs = set(self.api[a].device for a in alarms)
                     for d in devs:
                         try:
                             self.api.get_device(d).init()
                         except:
                             traceback.print_exc()
-                
+
         except Exception:
-            Qt.QMessageBox.critical(None,"Error", traceback.format_exc())
+            Qt.QMessageBox.critical(None, "Error", traceback.format_exc())
             return
         self.onCancel()
         self.pB.onRefresh()
-        Qt.QMessageBox.information(None,"Phonebook","%s added succesfully!"%name)
+        Qt.QMessageBox.information(None, "Phonebook", "{} added succesfully!".format(name))
 
     def onCancel(self):
         self._Form.close()
 
     def onCheckStateChanged(self, state):
-        if state==0:
+        if state == 0:
             self.smsLabel.setEnabled(False)
             self.smsLine.setEnabled(False)
         else:
             self.smsLabel.setEnabled(True)
             self.smsLine.setEnabled(True)
 
+
 class PhoneBookUi(object):
-    api=None
-    def __init__(self,api=None):
+    api = None
+
+    def __init__(self, api=None):
         type(self).api = api or self.api or panic.current()
         object.__init__(self)
 
@@ -188,48 +195,49 @@ class PhoneBookUi(object):
         QtCore.QMetaObject.connectSlotsByName(Form)
 
     def retranslateUi(self, Form):
-        Form.setWindowTitle(QtGui.QApplication.translate("Form", "Phonebook", None, QtGui.QApplication.UnicodeUTF8))
-        self.addButton.setText(QtGui.QApplication.translate("Form", "Add", None, QtGui.QApplication.UnicodeUTF8))
+        Form.setWindowTitle(QtGui.QApplication.translate("Form", "Phonebook", None))
+        self.addButton.setText(QtGui.QApplication.translate("Form", "Add", None))
         self.addButton.setIcon(getThemeIcon("list-add"))
         self.addButton.setToolTip("Add person to the list")
-        self.removeButton.setText(QtGui.QApplication.translate("Form", "Remove", None, QtGui.QApplication.UnicodeUTF8))
+        self.removeButton.setText(QtGui.QApplication.translate("Form", "Remove", None))
         self.removeButton.setIcon(getThemeIcon("list-remove"))
         self.removeButton.setToolTip("Remove person from list")
-        self.refreshButton.setText(QtGui.QApplication.translate("Form", "Refresh", None, QtGui.QApplication.UnicodeUTF8))
+        self.refreshButton.setText(QtGui.QApplication.translate("Form", "Refresh", None))
         self.refreshButton.setIcon(getThemeIcon("view-refresh"))
         self.refreshButton.setToolTip("Refresh list")
 
-        QtCore.QObject.connect(self.tableWidget, QtCore.SIGNAL("itemDoubleClicked(QTableWidgetItem *)"), self.onEdit)
-        QtCore.QObject.connect(self.addButton,QtCore.SIGNAL("clicked()"), self.onAdd)
-        QtCore.QObject.connect(self.removeButton,QtCore.SIGNAL("clicked()"), self.onRemove)
-        QtCore.QObject.connect(self.refreshButton,QtCore.SIGNAL("clicked()"), self.onRefresh)
+        self.tableWidget.itemDoubleClicked.connect(self.onEdit)
+        self.addButton.clicked.connect(self.onAdd)
+        self.removeButton.clicked.connect(self.onRemove)
+        self.refreshButton.clicked.connect(self.onRefresh)
         Form.resize(430, 800)
 
     def buildList(self):
-        data=self.api.get_phonebook()
+        data = self.api.get_phonebook()
         self.tableWidget.setColumnCount(2)
         self.tableWidget.setRowCount(len(data))
-        #self.tableWidget.setHorizontalHeaderLabels(["",""])
-        #print data
+        # self.tableWidget.setHorizontalHeaderLabels(["",""])
+        # print data
         i = 0
-        for name,value in sorted(data.items()):
-            for k in (name,value):
+        for name, value in sorted(data.items()):
+            for k in (name, value):
                 item = QtGui.QTableWidgetItem(k)
-                #if k.split('#')[0].strip():
-                    #item.setFlags(QtCore.Qt.ItemIsEnabled)
-                if not (i/2)%2:
-                    item.setBackgroundColor(QtGui.QColor(225,225,225))
-                self.tableWidget.setItem(int(i/2),i%2,item)
-                i+=1
+                # if k.split('#')[0].strip():
+                # item.setFlags(QtCore.Qt.ItemIsEnabled)
+                if not (i / 2) % 2:
+                    item.setBackground(QtGui.QColor(225, 225, 225))
+                self.tableWidget.setItem(int(i / 2), i % 2, item)
+                i += 1
             self.tableWidget.resizeColumnsToContents()
 
     def onEdit(self):
         ##pid=self.tableWidget.currentRow()-1
         ##alter=(str(self.tableWidget.item(pid,1).text()))
         ##self.api.edit_phonebook(alter)
-        #self.buildList()
-        name,value = map(str,(self.tableWidget.item(self.tableWidget.currentRow(),0).text(),self.tableWidget.item(self.tableWidget.currentRow(),1).text()))
-        print 'PhoneBook.onEdit(%s,%s)'%(name,value)
+        # self.buildList()
+        name, value = map(str, (self.tableWidget.item(self.tableWidget.currentRow(), 0).text(),
+                                self.tableWidget.item(self.tableWidget.currentRow(), 1).text()))
+        print('PhoneBook.onEdit({},{})'.format(name, value))
         try:
             self.prompt = Qt.QWidget()
             self.promptUi = PhoneBookEntry(self)
@@ -238,7 +246,7 @@ class PhoneBookUi(object):
             self.promptUi.emailLine.setText(value)
             self.prompt.show()
         except:
-            print traceback.format_exc()
+            print(traceback.format_exc())
 
     def onAdd(self):
         try:
@@ -247,25 +255,27 @@ class PhoneBookUi(object):
             self.promptUi.addSetupUi(self.prompt)
             self.prompt.show()
         except:
-            print traceback.format_exc()
+            print(traceback.format_exc())
 
     def onRemove(self):
-        name,value = map(str,(self.tableWidget.item(self.tableWidget.currentRow(),0).text(),self.tableWidget.item(self.tableWidget.currentRow(),1).text()))
-        reply=Qt.QMessageBox.question(None,"Remove","Do You Want to Remove %s?"%name, Qt.QMessageBox.Yes | QtGui.QMessageBox.No, QtGui.QMessageBox.Yes)
+        name, value = map(str, (self.tableWidget.item(self.tableWidget.currentRow(), 0).text(),
+                                self.tableWidget.item(self.tableWidget.currentRow(), 1).text()))
+        reply = Qt.QMessageBox.question(None, "Remove", "Do You Want to Remove {}?".format(name),
+                                        Qt.QMessageBox.Yes | QtGui.QMessageBox.No, QtGui.QMessageBox.Yes)
         if reply == QtGui.QMessageBox.Yes:
             try:
                 self.api.remove_phonebook(name)
                 self.onRefresh()
-                Qt.QMessageBox.information(None,"Remove","%s Removed"%name)
+                Qt.QMessageBox.information(None, "Remove", "{} Removed".format(name))
             except:
-                print traceback.format_exc()
-                Qt.QMessageBox.critical(None,"Problem", "Could not remove selected person<br>")
+                print(traceback.format_exc())
+                Qt.QMessageBox.critical(None, "Problem", "Could not remove selected person<br>")
 
     def onRefresh(self):
         self.buildList()
 
+
 if __name__ == "__main__":
-    import sys
     app = QtGui.QApplication(sys.argv)
     form = PhoneBook()
     form.show()
