@@ -1,15 +1,17 @@
-from utils import QtCore, QtGui
-from utils import clickableQLineEdit, clickableQTextEdit,getThemeIcon
+from taurus.external.qt import QtCore, QtGui
+from panic.gui.utils import (clickableQLineEdit, clickableQTextEdit, 
+                             getThemeIcon, AlarmFormula)
 
 """
 ui_data.py, this file contains the Ui Classes used for AlarmEditor form.
 """
 
+
 ######################################################################################
-class Ui_Data(object): 
-    #Alarm Editor
+class Ui_Data(object):
+    # Alarm Editor
     def setupUi(self, Data):
-        self.Data=Data
+        self.Data = Data
         Data.setObjectName("Data")
         Data.resize(349, 275)
         self.verticalLayout_3 = QtGui.QVBoxLayout(Data)
@@ -34,7 +36,7 @@ class Ui_Data(object):
         self.horizontalLane = QtGui.QHBoxLayout()
         self.horizontalLane.setObjectName("horizontalLayout")
         self.gridLayout.addLayout(self.horizontalLane, 1, 1, 1, 3)
-        
+
         self.disableLabel = QtGui.QLabel(Data)
         self.disableLabel.setObjectName("disableLabel")
         self.gridLayout.addWidget(self.disableLabel, 2, 0, 1, 1)
@@ -50,7 +52,6 @@ class Ui_Data(object):
         self.gridLayout.addWidget(self.ackCheckBox, 3, 1, 1, 1)
         self.ackCheckBox.setEnabled(False)
 
-
         self.deviceLabel = QtGui.QLabel(Data)
         self.deviceLabel.setObjectName("deviceLabel")
         self.gridLayout.addWidget(self.deviceLabel, 4, 0, 1, 1)
@@ -65,22 +66,22 @@ class Ui_Data(object):
         self.deviceStackedLayout.addWidget(self.deviceLineEdit)
         self.deviceStackedLayout.setCurrentIndex(1)
         self.gridLayout.addLayout(self.deviceStackedLayout, 4, 1, 1, 2)
-        
+
         self.deviceConfig = QtGui.QPushButton(Data)
         self.deviceConfig.setIcon(getThemeIcon("applications-system"))
         self.gridLayout.addWidget(self.deviceConfig, 4, 3, 1, 1)
-        
+
         self.severityLabel = QtGui.QLabel(Data)
         self.severityLabel.setObjectName("severityLabel")
         self.gridLayout.addWidget(self.severityLabel, 5, 0, 1, 1)
         self.severityStackedLayout = QtGui.QStackedLayout()
         self.severityStackedLayout.setObjectName("severityStackedLayout")
-        self.severityCombo=QtGui.QComboBox(Data)
+        self.severityCombo = QtGui.QComboBox(Data)
         self.severityCombo.setObjectName("severityCombo")
-        #self.severityCombo.connect(self.severityCombo,
-        #Q.textChanged,self.severityLineEdit.setText)
+        # self.severityCombo.connect(self.severityCombo,
+        # Q.textChanged,self.severityLineEdit.setText)
         self.severityStackedLayout.addWidget(self.severityCombo)
-        self.severityLineEdit=clickableQLineEdit(Data)
+        self.severityLineEdit = clickableQLineEdit(Data)
         self.severityLineEdit.setReadOnly(True)
         self.severityLineEdit.setObjectName("severityLineEdit")
         self.severityStackedLayout.addWidget(self.severityLineEdit)
@@ -107,7 +108,7 @@ class Ui_Data(object):
         self.wikiLink = QtGui.QLabel(Data)
         self.wikiLink.setObjectName("wikiLlink")
         self.wikiLink.setOpenExternalLinks(True)
-        self.gridLayout.addWidget(self.wikiLink,7,1,1,3)
+        self.gridLayout.addWidget(self.wikiLink, 7, 1, 1, 3)
 
         self.receiversLabel = QtGui.QLabel(Data)
         self.receiversLabel.setObjectName("receiversLabel")
@@ -126,7 +127,7 @@ class Ui_Data(object):
 
         self.receiversWidget = QtGui.QWidget(Data)
         self.receiversWidget.setObjectName("receiversWidget")
-#        self.receiversStackedLayout.addWidget(self.receiversWidget)
+        #        self.receiversStackedLayout.addWidget(self.receiversWidget)
         self.receiversStackedLayout.setCurrentIndex(0)
 
         self.horizontalLayout.addLayout(self.receiversStackedLayout)
@@ -158,20 +159,19 @@ class Ui_Data(object):
         sizePolicy.setHeightForWidth(self.formulaWidget.sizePolicy().hasHeightForWidth())
         self.formulaWidget.setSizePolicy(sizePolicy)
         self.formulaWidget.setObjectName("formulaWidget")
-        self.formulaStacked.addWidget(self.formulaWidget) # ad widget to stacked
+        self.formulaStacked.addWidget(self.formulaWidget)  # ad widget to stacked
 
         self.verticalLayout_2 = QtGui.QVBoxLayout(self.formulaWidget)
         self.verticalLayout_2.setObjectName("verticalLayout_2")
-        self.formulaLabel = QtGui.QLabel()#self.formulaWidget)
-        #self.font = QtGui.QFont()
-        #self.font.setPointSize(8)
-        #self.font.setWeight(75)
-        #self.font.setBold(True)
-        #self.formulaLabel.setFont(self.font)
-        #self.formulaLabel.setObjectName("formulaLabel")
-        #self.verticalLayout_2.addWidget(self.formulaLabel)
-        from utils import AlarmFormula
-        self.formulaTextEdit = AlarmFormula() #clickableQTextEdit(self.formulaWidget)
+        self.formulaLabel = QtGui.QLabel()  # self.formulaWidget)
+        # self.font = QtGui.QFont()
+        # self.font.setPointSize(8)
+        # self.font.setWeight(75)
+        # self.font.setBold(True)
+        # self.formulaLabel.setFont(self.font)
+        # self.formulaLabel.setObjectName("formulaLabel")
+        # self.verticalLayout_2.addWidget(self.formulaLabel)
+        self.formulaTextEdit = AlarmFormula()  # clickableQTextEdit(self.formulaWidget)
         self.formulaTextEdit.setReadOnly(True)
         self.formulaTextEdit.setObjectName("formulaTextEdit")
         self.verticalLayout_2.addWidget(self.formulaTextEdit)
@@ -232,12 +232,13 @@ class Ui_Data(object):
         self.cancelButton.setText("Cancel")
         self.saveButton.setText("Save")
 
+
 ##########################################################################################################
 
 class Ui_ReceiversLine(object):
     # Receivers Chooser
     def setupUi(self, ReceiversLine):
-        self.ReceiversLine=ReceiversLine
+        self.ReceiversLine = ReceiversLine
         ReceiversLine.setObjectName("ReceiversLine")
         ReceiversLine.resize(303, 67)
         self.verticalLayout = QtGui.QVBoxLayout(ReceiversLine)
@@ -258,21 +259,24 @@ class Ui_ReceiversLine(object):
         self.verticalLayout.addLayout(self.gridLayout)
 
         self.retranslateUi(ReceiversLine)
-        QtCore.QObject.connect(self.okButton, QtCore.SIGNAL("clicked(bool)"), ReceiversLine.close)
-        QtCore.QObject.connect(self.cancelButton, QtCore.SIGNAL("clicked(bool)"), ReceiversLine.close)
+        self.okButton.clicked.connect(ReceiversLine.close)
+        self.cancelButton.clicked.connect(ReceiversLine.close)
         QtCore.QMetaObject.connectSlotsByName(ReceiversLine)
 
     def retranslateUi(self, ReceiversLine):
-        ReceiversLine.setWindowTitle(QtGui.QApplication.translate("ReceiversLine", "Form", None, QtGui.QApplication.UnicodeUTF8))
-        self.okButton.setText(QtGui.QApplication.translate("ReceiversLine", "Ok", None, QtGui.QApplication.UnicodeUTF8))
-        self.cancelButton.setText(QtGui.QApplication.translate("ReceiversLine", "Cancel", None, QtGui.QApplication.UnicodeUTF8))
-        
+        ReceiversLine.setWindowTitle(
+            QtGui.QApplication.translate("ReceiversLine", "Form", None))
+        self.okButton.setText(QtGui.QApplication.translate("ReceiversLine", "Ok", None))
+        self.cancelButton.setText(
+            QtGui.QApplication.translate("ReceiversLine", "Cancel", None))
+
+
 ##########################################################################################################
-        
+
 class uiBodyForm(object):
     # Formula Editor
     def setupUi(self, Form):
-        self.Form=Form
+        self.Form = Form
         Form.setObjectName("Form")
         Form.resize(346, 219)
         sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Expanding)
@@ -363,15 +367,19 @@ class uiBodyForm(object):
         self.verticalLayout_2.addLayout(self.gridLayout)
 
         self.retranslateUi(Form)
-        QtCore.QObject.connect(self.rowEditButton, QtCore.SIGNAL("clicked(bool)"), self.formulaLineEdit.setDisabled)
+        self.rowEditButton.clicked.connect(self.formulaLineEdit.setDisabled)
         QtCore.QMetaObject.connectSlotsByName(Form)
 
     def retranslateUi(self, Form):
-        Form.setWindowTitle(QtGui.QApplication.translate("Form", "Form", None, QtGui.QApplication.UnicodeUTF8))
-        self.addExpressionButton.setText(QtGui.QApplication.translate("Form", "Add Expression", None, QtGui.QApplication.UnicodeUTF8))
-        self.addRelationButton.setText(QtGui.QApplication.translate("Form", "Add Relation", None, QtGui.QApplication.UnicodeUTF8))
-        self.clearButton.setText(QtGui.QApplication.translate("Form", "Clear", None, QtGui.QApplication.UnicodeUTF8))
-        self.rowEditButton.setText(QtGui.QApplication.translate("Form", "Raw Edit", None, QtGui.QApplication.UnicodeUTF8))
+        Form.setWindowTitle(QtGui.QApplication.translate("Form", "Form", None))
+        self.addExpressionButton.setText(
+            QtGui.QApplication.translate("Form", "Add Expression", None))
+        self.addRelationButton.setText(
+            QtGui.QApplication.translate("Form", "Add Relation", None))
+        self.clearButton.setText(QtGui.QApplication.translate("Form", "Clear", None))
+        self.rowEditButton.setText(
+            QtGui.QApplication.translate("Form", "Raw Edit", None))
+
 
 ########################################################################################################
 
@@ -387,7 +395,7 @@ class uiRowForm(object):
         sizePolicy.setHeightForWidth(row_widget.sizePolicy().hasHeightForWidth())
         row_widget.setSizePolicy(sizePolicy)
         self.gridLayout = QtGui.QGridLayout(row_widget)
-        self.gridLayout.setMargin(0)
+        self.gridLayout.setContentsMargins(0,0,0,0)
         self.gridLayout.setObjectName("gridLayout")
         self.valueCombo = QtGui.QComboBox(row_widget)
         sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Preferred, QtGui.QSizePolicy.Fixed)
@@ -433,10 +441,11 @@ class uiRowForm(object):
         self.gridLayout.addWidget(self.removeButton, 1, 3, 1, 1)
         self.retranslateUi(row_widget)
 
-        QtCore.QObject.connect(self.variableCombo, QtCore.SIGNAL("editTextChanged(QString)"), self.row_widget.CreateText)
-        QtCore.QObject.connect(self.operatorCombo, QtCore.SIGNAL("editTextChanged(QString)"), self.row_widget.CreateText)
-        QtCore.QObject.connect(self.valueCombo, QtCore.SIGNAL("currentIndexChanged(QString)"), self.row_widget.CreateText)
+        self.variableCombo.editTextChanged.connect(self.row_widget.CreateText)
+        self.operatorCombo.editTextChanged.connect(self.row_widget.CreateText)
+        self.valueCombo.currentIndexChanged.connect(self.row_widget.CreateText)
         QtCore.QMetaObject.connectSlotsByName(row_widget)
 
     def retranslateUi(self, row_widget):
-        row_widget.setWindowTitle(QtGui.QApplication.translate("row_widget", "Form", None, QtGui.QApplication.UnicodeUTF8))
+        row_widget.setWindowTitle(
+            QtGui.QApplication.translate("row_widget", "Form", None))
